@@ -71,13 +71,14 @@
 
 #include <algorithm>
 #include <functional>
+#include <memory>
 #include <unordered_map>
 
 namespace qbs {
 namespace Internal {
 
-BuildGraphLoader::BuildGraphLoader(const Logger &logger) :
-    m_logger(logger)
+BuildGraphLoader::BuildGraphLoader(Logger logger) :
+    m_logger(std::move(logger))
 {
 }
 
@@ -273,7 +274,7 @@ static void updateProductAndRulePointers(const ResolvedProductPtr &newProduct)
             const auto it = ruleMap.find(oldRule);
             if (it != ruleMap.cend())
                 return it->second;
-            for (const RuleConstPtr &r : qAsConst(newProduct->rules)) {
+            for (const auto &r : qAsConst(newProduct->rules)) {
                 if (*r == *oldRule) {
                     ruleMap.insert(std::make_pair(oldRule, r));
                     return r;
@@ -362,7 +363,7 @@ void BuildGraphLoader::trackProjectChanges()
     ChildListHash childLists;
     if (!changedProducts.empty()) {
         oldBuildData = std::make_shared<ProjectBuildData>(restoredProject->buildData.get());
-        for (const ResolvedProductConstPtr &product : qAsConst(allRestoredProducts)) {
+        for (const auto &product : qAsConst(allRestoredProducts)) {
             if (!product->buildData)
                 continue;
 
@@ -438,11 +439,10 @@ void BuildGraphLoader::trackProjectChanges()
                                                       allNewlyResolvedProducts);
     }
 
-    for (auto it = m_changedSourcesByProduct.cbegin(); it != m_changedSourcesByProduct.cend();
-         ++it) {
-        const ResolvedProductPtr product = m_freshProductsByName.value(it->first);
+    for (const auto &kv : m_changedSourcesByProduct) {
+        const ResolvedProductPtr product = m_freshProductsByName.value(kv.first);
         QBS_CHECK(!!product);
-        for (const SourceArtifactConstPtr &sa : it->second)
+        for (const SourceArtifactConstPtr &sa : kv.second)
             updateArtifactFromSourceArtifact(product, sa);
     }
 
@@ -452,7 +452,7 @@ void BuildGraphLoader::trackProjectChanges()
         updateGeneratedArtifacts(product.get());
     }
 
-    for (const ResolvedProductConstPtr &changedProduct : qAsConst(changedProducts)) {
+    for (const auto &changedProduct : qAsConst(changedProducts)) {
         rescueOldBuildData(changedProduct,
                            m_freshProductsByName.value(changedProduct->uniqueName()),
                            childLists, rescuableArtifactData.value(changedProduct->uniqueName()));
@@ -615,7 +615,7 @@ bool BuildGraphLoader::hasProductFileChanged(const std::vector<ResolvedProductPt
                         FileInfo::path(group->location.filePath()),
                         product->topLevelProject()->buildDirectory);
                 Set<QString> wcFiles;
-                for (const SourceArtifactConstPtr &sourceArtifact : group->wildcards->files)
+                for (const auto &sourceArtifact : group->wildcards->files)
                     wcFiles += sourceArtifact->absoluteFilePath;
                 if (files == wcFiles)
                     continue;
@@ -742,9 +742,9 @@ static bool dependenciesAreEqual(const ResolvedProductConstPtr &p1,
         return false;
     Set<QString> names1;
     Set<QString> names2;
-    for (const ResolvedProductConstPtr &dep : qAsConst(p1->dependencies))
+    for (const auto &dep : qAsConst(p1->dependencies))
         names1 << dep->uniqueName();
-    for (const ResolvedProductConstPtr &dep : qAsConst(p2->dependencies))
+    for (const auto &dep : qAsConst(p2->dependencies))
         names2 << dep->uniqueName();
     return names1 == names2;
 }
@@ -910,7 +910,7 @@ void BuildGraphLoader::rescueOldBuildData(const ResolvedProductConstPtr &restore
     if (!restoredProduct->buildData)
         return;
     if (!newlyResolvedProduct->buildData)
-        newlyResolvedProduct->buildData.reset(new ProductBuildData);
+        newlyResolvedProduct->buildData = std::make_unique<ProductBuildData>();
 
     qCDebug(lcBuildGraph) << "rescue data of product" << restoredProduct->uniqueName();
     QBS_CHECK(newlyResolvedProduct->buildData);
